package lauegramm;

import java.awt.*;
import java.awt.event.*;
import java.applet.Applet;


/**
 * This file is part of lauegramm.
 * lauegramm is a Java application/applet, which renders a crystal in real space
 * and the Laue back-scattering obtained by a white beam,
 * together with a graphical user interface.
 * Copyright 2008, Michael Leitner
 *
 * As stated below, you are free to do whatever you want with this program, as long as
 * it conforms to the licence, but I would be glad to hear if someone found it useful,
 * so please tell me if so under michael.leitner@univie.ac.at
 *
 * lauegramm is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * lauegramm is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

public class LGApplet extends Applet implements ActionListener,ItemListener {
    Lattice lattice;
    Orientation orientation;
    RealCanvas realCanvas;
    LaueCanvas laueCanvas;
    ControlPanel controlPanel=new ControlPanel(this,this);
    
    public LGApplet() {
        setBackground(Color.lightGray);
        setLayout(new FlowLayout());
        orientation=new Orientation();
        lattice = new Lattice(orientation);
        laueCanvas=new LaueCanvas(lattice,orientation);
        realCanvas=new RealCanvas(lattice,orientation,laueCanvas);
        add(realCanvas);                   
        add(controlPanel);     
        add(laueCanvas);                        
        actionPerformed(new ActionEvent(new Button(),0,""));
        controlPanel.itemStateChanged();
        setVisible(true);
    }

    public void actionPerformed(ActionEvent event) {
        int i;
        String string=controlPanel.basisCBG.getSelectedCheckbox().getLabel();
        if (string.equals("primitive"))
            i=0;
        else if (string.equals("body-centered"))
            i=1;
        else if (string.equals("face-centered"))
            i=2;
        else if (string.equals("base-centered"))
            i=3;
        else if (string.equals("diamond"))
            i=4;
        else 
            i=5;
        lattice.choose(controlPanel.latticeType.getSelectedItem(),i,Double.parseDouble(controlPanel.textFields[0].getText()),Double.parseDouble(controlPanel.textFields[1].getText()),Double.parseDouble(controlPanel.textFields[2].getText()),Double.parseDouble(controlPanel.textFields[3].getText()),Double.parseDouble(controlPanel.textFields[4].getText()),Double.parseDouble(controlPanel.textFields[5].getText()),Integer.parseInt(controlPanel.textFields[6].getText()),Integer.parseInt(controlPanel.textFields[7].getText()),Integer.parseInt(controlPanel.textFields[8].getText()));
        realCanvas.zoomFactor=Double.parseDouble(controlPanel.textFields[9].getText())/10.;
        realCanvas.radius=Double.parseDouble(controlPanel.textFields[10].getText());
        realCanvas.repaint();
        
    }
    
    public void itemStateChanged(ItemEvent event) {
        if (event.getStateChange()==ItemEvent.DESELECTED)
            remove(2);
        else if (event.getStateChange()==ItemEvent.SELECTED)
            add(laueCanvas,2);
    }
}